!Programma per calcolare magnitudini e colori:
!1) Bande e funzioni risposta (bande.dat): 
!   UBVRI NORMALIZED PASSBANDS da Bessel 1990, PASP, 102, 1181, Table 2
!   JHKLM                      da Bessel & Brett 1988, PASP, 100, 1134, Table IV (senza errori!) 
!   La banda UX non e' reliable per la mag U, serve per il colore U-B da calcolare
!   con BX.
!2) Punti zero:
!   con i flussi a mag zero e lambda eff presi dalla tesi di Gian (v.li'refs)+
!   lo spettro di Vega (vegahs.spe, Strecker et al.79,Ap.J.S.S.,41:510 tra
!	1.2 e 5.5 microns e Hayes 85,IAU reports,p247 tra .33 e 1.05 microns) ho 	
!   le mag di Vega da cui calcolare le costanti di calibrazione
!   = mag_vega+2.5*log<f(lam)_vega>_banda.
!   Queste sono lette come flussi a mag zero in bande.dat. 
!   Le calibrazioni di partenza e quelle derivate sono in zpvegahs.spe;
!   mags e colori trovati per Vega con queste nuove calibrazioni e bande passanti sono
!   in colvegahs.spe. 
!   La calibrazione di partenza della banda I e' invece presa da Bessel&Brett1988.
!   Per rifare i conti dei punti zero basta mettere .false. nell' if subito
!   dopo il calcolo di flumed in ci.for e dare vegahs.spe come argomento (e
!   ovviamente mettere in bande.dat le vecchie calibrazioni).
!3) Run del programma: 
!   il nome del file dello spettro va dato come primo argomento. 
!   Se c'e' un solo arg si calcolano le mags assolute e i colori.
!   Gli eventuali altri argomento sono redshift, omega, H_o. Vanno dati
!   scrivendo redshift=* omega=* H_o=* in qualsiasi ordine.
!   In tal caso si calcolano le mags apparenti. 
!   Il programma si puo' lanciare da qualsiasi directory, bande.dat viene
!   cercato nella stessa directory dell' eseguibile; lo spettro di input e 
!   e gli outputs sono nella directory corrente. 
!4) Outputs:.....
!5) Si possono calcolare i colori anche per uno spettro di BB+PL+per punti
!   usando nella qromb la function FLU_OLD invece della FLU nel calcolo 
!   del flusso medio in ci.for. L' input per la flu_old e' ci.par.

!N.B. i conti sono fatti per flussi e lambda in erg/cm^2/s/A e A risp.
!           
!****************************

module modname

character(len=80)::name,name_dir
!name_dir is the name of the directory of the input data files
!(bande.dat)

end module modname

!****************************

module parametri

!variabili e altro che servono per gli eventuali parametri (z,omega,H_o)
!dati in input come argomenti dopo il nome del file dello spettro:

character(80), dimension(:), allocatable:: opt
integer,save:: nopt
!opt is an array (to be allocated to nopt elements) of strings for command 
!line options (if no second argument -> absolute mags are computed; if
!present, they are redshift, omega, H_o)

type partype
   character*10::name
   logical::found
end type partype

integer, parameter:: npar=4  !!!lqui

type (partype), dimension(npar)::par

character(len=10)::key
real::val
real, save:: redshift, omega, H_o, lambda=0. !!!lqui 

logical, parameter:: rest=.false.  !true=evoluzione nel rest frame,false=observed frame

contains  

!***********

  subroutine params
  implicit none
  character(len=10):: valstr
  integer::i 

  par%name=(/'redshift  ','omega     ','H_o       ','lambda    '/)  !!!lqui
  par%found=.false.

  write(*,*) nopt

  DO i=1,nopt
 ! passaggio intermedio per valstr in modo da poter fare un lettura
 ! non formattata e quindi entrare reali anche senza punto decimale
    READ (opt(i),'(2a10)') KEY,VALSTR
	write(*,'(1x,i,1x,2a10)') i, key,valstr
	write(*,'(a10)') par(i)%name
    read (VALSTR,*) val 
    call setpar
  ENDDO

  par(4)%found=.TRUE. !lambda is optional (and it is initialized to 0)
  IF (any(.not.par%found)) THEN
       WRITE (*,*) 'FATAL ERROR - missing parameter(s)'
        do i=1,npar
              if (.not.par(i)%found) then
                 write (*,*) par(i)%name
              endif
	     enddo
         stop
  ENDIF

  end subroutine params

!***********

  subroutine setpar
  implicit none
  integer:: i

  IF (KEY==par(1)%name) THEN
      redshift=VAL
      par(1)%found=.TRUE.
  ELSE IF (KEY==par(2)%name) THEN
      omega=VAL
      par(2)%found=.TRUE.
  ELSE IF (KEY==par(3)%name) THEN
      H_o=VAL
      par(3)%found=.TRUE.
  ELSE IF (KEY==par(4)%name) THEN  !!!lqui
      lambda=VAL
      par(4)%found=.TRUE.
  ELSE
      print *, "ERROR: unknown key in input arguments"
      stop
  ENDIF

  end subroutine setpar

!***********

end module parametri

!****************************

PROGRAM COLORI

use dfport ! solo per DIGITAL VISUAL FORTRAN
use msflib ! solo per fortran MSPWS
use modname
use parametri

implicit none

integer*2::i
integer::j
character*80::scra


! name e' il nome completo dello spettro di cui voglio
! i colori, compresa l' estensione. Il nome del file di output
! e' 'col'//name o colevol.out se ci sono redshift, omega, Ho. 
 
call getarg(1_2,name)

if (arg_empty(name)) then
     write(*,10)
else 
     call getarg(0_2,name_dir)
     call clean_name_dir
      
     !per il momento usero' al max 3 argomenti oltre al nome
	 !dello spettro, cioe' il redshift,omega,H_o, ma lascio la 
	 !possibilita' di dare in input piu' argomenti

     nopt=iargc()-1
     if (nopt>0) then
        if (nopt < npar-1) then  !lambda opzionale !!!lqui
            print *, "manca redshift, omega, H_o o lambda!"
            stop
        endif
        allocate(opt(nopt),STAT=i)
        IF (I.NE. 0) THEN
            PRINT *, "ALLOCATION ERROR IN CI_INI"
            STOP
        ENDIF

        do i=1,nopt
           call getarg(i+1,scra)
           j=INDEX(scra,'=')-1
           if (j<=0) then
              print *,   &
              'Invalid argument in command line (missing =)'
              stop
           else
              opt(i)(1:10) = scra(1:j)
              opt(i)(11:20) = scra(j+2:)
           endif
        enddo         
        call params
     endif

     call c_i

     if (allocated(opt)) deallocate(opt)

endif


10   format(                                 &
     ' I need one argument to run!'/         &
     ' Usage: colori model_name',/,   &
     ' Try again!')

contains
!*********
  function arg_empty(arg)
! tests if the command line argument in the string arg is
! empty. This complication arises because in this case 
! win95/nt getarg returns a string of char(0) (nul) whilst 
! on unix a string of spaces.
  implicit none
  character (len=*),intent(in)::arg
  logical::arg_empty

  arg_empty=(arg(1:1)==char(0).or.arg(1:1)==' ')

  end function arg_empty
!*********
  subroutine clean_name_dir

  use modname
  implicit none
  integer::last

  last=scan(name_dir,'/\',back=.true.)

  if (last==0) then
     name_dir=' '
  else
     name_dir=name_dir(1:last)
  endif

  end subroutine clean_name_dir
!*********

END PROGRAM COLORI
